@@ -1,11 +1,10 @@
-#
 
 package Mail::Cap;
 use strict;
 
 use vars qw($VERSION $useCache);
 
-$VERSION = "1.06";
+$VERSION = "1.07";
 sub Version { $VERSION; }
 
 =head1 NAME
@@ -46,7 +45,9 @@ if($^O eq "MacOS") {
 } else {
     @path = split(/:/, $ENV{MAILCAPS} ||
 	# this path is specified under RFC 1524 appendix A 
-	"$ENV{HOME}/.mailcap:/etc/mailcap:/usr/etc/mailcap:/usr/local/etc/mailcap");
+	( defined($ENV{HOME})
+	  ? "$ENV{HOME}/.mailcap:/etc/mailcap:/usr/etc/mailcap:/usr/local/etc/mailcap"
+	  : "/etc/mailcap:/usr/etc/mailcap:/usr/local/etc/mailcap"));
 }
 
 
@@ -76,6 +77,7 @@ sub new
 	}
     }
     my $self = bless {}, $class;
+    local *MAILCAP;
     if (defined $file && open(MAILCAP, $file)) {
 	$self->{'_file'} = $file;
       local($_);
@@ -137,7 +139,7 @@ sub new
 
 These methods invoke a suitable progam presenting or manipulating the
 media object in the specified file.  They all return C<1> if a command
-was found, and C<0> otherwise.  You might test C<$?" for the outcome
+was found, and C<0> otherwise.  You might test C<$?> for the outcome
 of the command.
 
 =cut
@@ -327,7 +329,9 @@ modify it under the same terms as Perl itself.
 
 Gisle Aas <aas@oslonett.no> 
 
-Maintained by Graham Barr <gbarr@pobox.com>
+Modified by Graham Barr <gbarr@pobox.com>
+
+Maintained by Mark Overmeer <mailtools@overmeer.net>
 
 =cut
 
