@@ -1,160 +1,40 @@
 # Mail::Field.pm
 #
-# Copyright (c) 1995 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 1995-2001 Graham Barr. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
 package Mail::Field;
-use strict;
-
-=head1 NAME
-
-Mail::Field - Base class for manipulation of mail header fields
-
-=head1 SYNOPSIS
-
-    use Mail::Field;
-    
-    $field = Mail::Field->new('Subject', 'some subject text');
-    print $field->tag,": ",$field->stringify,"\n";
-
-    $field = Mail::Field->subject('some subject text');
-
-=head1 DESCRIPTION
-
-C<Mail::Field> is a base class for packages that create and manipulate
-fields from Email (and MIME) headers. Each different field will have its
-own sub-class, defining its own interface.
-
-This document describes the minimum interface that each sub-class should
-provide, and also guidlines on how the field specific interface should be
-defined. 
-
-=head1 CONSTRUCTOR
-
-Mail::Field, and it's sub-classes define several methods which return
-new objects. These can all be termed to be constructors.
-
-=over 4
-
-=item new ( TAG [, STRING | OPTIONS ] )
-
-The new constructor will create an object in the class which defines
-the field specified by the tag argument.
-
-After creation of the object :-
-
-If the tag argument is followed by a single string then the C<parse> method
-will be called with this string.
-
-If the tag argument is followed by more than one arguments then the C<create>
-method will be called with these arguments.
-
-=item extract ( TAG, HEAD [, INDEX ] )
-
-This constuctor takes as arguments the tag name, a C<Mail::Head> object
-and optionally an index.
-
-If the index argument is given then C<extract> will retrieve the given tag
-from the C<Mail::Head> object and create a new C<Mail::Field> based object.
-I<undef> will be returned in the field does not exist.
-
-If the index argument is not given the the result depends on the context
-in which C<extract> is called. If called in a scalar context the result
-will be as if C<extract> was called with an index value of zero. If called
-in an array context then all tags will be retrieved and a list of
-C<Mail::Field> objects will be returned.
-
-=item combine ( FIELD_LIST )
-
-This constructor takes as arguments a list of C<Mail::Field> objects, which
-should all be of the same sub-class, and creates a new object in that same
-class.
-
-This constructor is nor defined in C<Mail::Field> as there is no generic
-way to combine the various field types. Each sub-class should define
-its own combine constructor, if combining is possible/allowed.
-
-=back
-
-=head1 METHODS
-
-=over 4
-
-=item parse
-
-=item set
-
-=item tag
-
-=item stringify
-
-=back
-
-=head1 SUB-CLASS PACKAGE NAMES
-
-All sub-classes should be called Mail::Field::I<name> where I<name> is
-derived from the tag using these rules.
-
-=over 4
-
-=item *
-
-Consider a tag as being made up of elements separated by '-'
-
-=item *
-
-Convert all characters to lowercase except the first in each element, which
-should be uppercase.
-
-=item *
-
-I<name> is then created from these elements by using the first
-N characters from each element.
-
-=item *
-
-N is calculated by using the formula :-
-
-    int((7 + #elements) / #elements)
-
-=item *
-
-I<name> is then limited to a maximum of 8 characters, keeping the first 8
-characters
-
-=back
-
-For an example of this take a look at the definition of the 
-C<_header_pkg_name> subroutine in C<Mail::Field>
-
-=head1 AUTHOR
-
-Graham Barr <gbarr@pobox.com>
-
-=head1 SEE ALSO
-
-L<MIME::*>s
-
-=head1 CREDITS
-
-Eryq <eryq@rhine.gsfc.nasa.gov> - for all the help in defining this package
-so that Mail::* and MIME::* can be integrated together.
-
-=head1 COPYRIGHT
-
-Copyright (c) 1995 Graham Barr. All rights reserved. This program is free
-software; you can redistribute it and/or modify it under the same terms
-as Perl itself.
-
-=cut
 
+# $Id: //depot/MailTools/Mail/Field.pm#7 $
 
 use Carp;
 use strict;
 use vars qw($AUTOLOAD $VERSION);
 
-$VERSION = "1.05";
+$VERSION = "1.08";
+
+unless(defined &UNIVERSAL::can) {
+    *UNIVERSAL::can = sub {
+	my($obj,$meth) = @_;
+	my $pkg = ref($obj) || $obj;
+	my @pkg = ($pkg);
+	my %done;
+	while(@pkg) {
+            $pkg = shift @pkg;
+            next if exists $done{$pkg};
+            $done{$pkg} = 1;
+
+	    no strict 'refs';
+
+            unshift @pkg,@{$pkg . "::ISA"}
+        	if(@{$pkg . "::ISA"});
+            return \&{$pkg . "::" . $meth}
+        	if defined(&{$pkg . "::" . $meth});
+	}
+	undef;
+    }
+}
 
 sub _header_pkg_name
 {
@@ -194,7 +74,7 @@ sub _require_dir
      next
 	unless $f =~ /^([\w\-]+)/;
 
-     my $p = lc $1;
+     my $p = $1;
      my $n = $dir . $dir_sep . $p;
 
      if(-d $n )
@@ -261,7 +141,9 @@ sub register
  no strict 'refs';
  *{$method} = sub {
 	shift;
-	eval "require $pkg" || die $@;
+	unless ($pkg->can('stringify')) {
+	    eval "require $pkg" || die $@;
+	}
 	$pkg->_build(@_);
  };
 
@@ -477,3 +359,151 @@ sub stringify
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Mail::Field - Base class for manipulation of mail header fields
+
+=head1 SYNOPSIS
+
+    use Mail::Field;
+    
+    $field = Mail::Field->new('Subject', 'some subject text');
+    print $field->tag,": ",$field->stringify,"\n";
+
+    $field = Mail::Field->subject('some subject text');
+
+=head1 DESCRIPTION
+
+C<Mail::Field> is a base class for packages that create and manipulate
+fields from Email (and MIME) headers. Each different field will have its
+own sub-class, defining its own interface.
+
+This document describes the minimum interface that each sub-class should
+provide, and also guidlines on how the field specific interface should be
+defined. 
+
+=head1 CONSTRUCTOR
+
+Mail::Field, and it's sub-classes define several methods which return
+new objects. These can all be termed to be constructors.
+
+=over 4
+
+=item new ( TAG [, STRING | OPTIONS ] )
+
+The new constructor will create an object in the class which defines
+the field specified by the tag argument.
+
+After creation of the object :-
+
+If the tag argument is followed by a single string then the C<parse> method
+will be called with this string.
+
+If the tag argument is followed by more than one arguments then the C<create>
+method will be called with these arguments.
+
+=item extract ( TAG, HEAD [, INDEX ] )
+
+This constuctor takes as arguments the tag name, a C<Mail::Head> object
+and optionally an index.
+
+If the index argument is given then C<extract> will retrieve the given tag
+from the C<Mail::Head> object and create a new C<Mail::Field> based object.
+I<undef> will be returned in the field does not exist.
+
+If the index argument is not given the the result depends on the context
+in which C<extract> is called. If called in a scalar context the result
+will be as if C<extract> was called with an index value of zero. If called
+in an array context then all tags will be retrieved and a list of
+C<Mail::Field> objects will be returned.
+
+=item combine ( FIELD_LIST )
+
+This constructor takes as arguments a list of C<Mail::Field> objects, which
+should all be of the same sub-class, and creates a new object in that same
+class.
+
+This constructor is nor defined in C<Mail::Field> as there is no generic
+way to combine the various field types. Each sub-class should define
+its own combine constructor, if combining is possible/allowed.
+
+=back
+
+=head1 METHODS
+
+=over 4
+
+=item parse
+
+=item set
+
+=item tag
+
+=item stringify
+
+=back
+
+=head1 SUB-CLASS PACKAGE NAMES
+
+All sub-classes should be called Mail::Field::I<name> where I<name> is
+derived from the tag using these rules.
+
+=over 4
+
+=item *
+
+Consider a tag as being made up of elements separated by '-'
+
+=item *
+
+Convert all characters to lowercase except the first in each element, which
+should be uppercase.
+
+=item *
+
+I<name> is then created from these elements by using the first
+N characters from each element.
+
+=item *
+
+N is calculated by using the formula :-
+
+    int((7 + #elements) / #elements)
+
+=item *
+
+I<name> is then limited to a maximum of 8 characters, keeping the first 8
+characters
+
+=back
+
+For an example of this take a look at the definition of the 
+C<_header_pkg_name> subroutine in C<Mail::Field>
+
+=head1 AUTHOR
+
+Graham Barr.
+
+Maintained by Mark Overmeer <mailtools@overmeer.net>
+
+=head1 SEE ALSO
+
+L<MIME::*>s
+
+=head1 CREDITS
+
+Eryq <eryq@rhine.gsfc.nasa.gov> - for all the help in defining this package
+so that C<Mail::*> and C<MIME::*> can be integrated together.
+
+=head1 COPYRIGHT
+
+Copyright (c) 1995-2001 Graham Barr. All rights reserved. This program is free
+software; you can redistribute it and/or modify it under the same terms
+as Perl itself.
+
+=cut
+
+
