@@ -1,7 +1,7 @@
 # Mail::Internet.pm
 #
-# Copyright (c) 1995-8 Graham Barr <gbarr@pobox.com>. All rights
-# reserved. This program is free software; you can redistribute it and/or
+# Copyright (c) 1995-2001 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
 
@@ -16,7 +16,7 @@ use Mail::Header;
 use vars qw($VERSION);
 
 BEGIN {
-    $VERSION = "1.32";
+    $VERSION = "1.33";
     *AUTOLOAD = \&AutoLoader::AUTOLOAD;
 
     unless(defined &UNIVERSAL::isa) {
@@ -109,7 +109,7 @@ sub body
  if(@_)
   {
    my $new = shift;
-   $me->{'mail_inet_body'} = ref($new) eq 'ARRAY' ? $new : [ $new ];
+   $me->{'mail_inet_body'} = ref($new) eq 'ARRAY' ? $new : [ $new, @_ ];
   }
 
  return $body;
@@ -535,7 +535,7 @@ sub _prephdr {
 
     $hdr->replace('X-Mailer', "Perl5 Mail::Internet v" . $Mail::Internet::VERSION);
 
-    my $name = eval { (getpwuid($>))[6] } || $ENV{NAME} || "";
+    my $name = eval { local $SIG{__DIE__}; (getpwuid($>))[6] } || $ENV{NAME} || "";
 
     while($name =~ s/\([^\(\)]*\)//) { 1; }
 
@@ -573,7 +573,14 @@ use strict;
     my $smtp;
     my @hello = defined $opt{Hello} ? (Hello => $opt{Hello}) : ();
 
+    push(@hello, 'Port', $opt{'Port'})
+	if exists $opt{'Port'};
+
+    push(@hello, 'Debug', $opt{'Debug'})
+	if exists $opt{'Debug'};
+
     unless(defined($host)) {
+	local $SIG{__DIE__};
 	my @hosts = qw(mailhost localhost);
 	unshift(@hosts, split(/:/, $ENV{SMTPHOSTS})) if(defined $ENV{SMTPHOSTS});
 
@@ -587,6 +594,7 @@ use strict;
 	$noquit = 1;
     }
     else {
+	local $SIG{__DIE__};
 	$smtp = eval { Net::SMTP->new($host, @hello) };
     }
 
@@ -777,11 +785,16 @@ also be given.
 
 =over 4
 
-=item body ()
+=item body ( [ BODY ] )
 
 Returns the body of the message. This is a reference to an array.
 Each entry in the array represents a single line in the message.
 
+If I<BODY> is given, it can be a referenc to an aray or an array, then
+the body will be replaced. If a reference is passed, it is used directly
+and not copied, so any sunsequent changes to the array will change the
+contents of the body.
+
 =item print_header ( [ FILEHANDLE ] )
 
 =item print_body ( [ FILEHANDLE ] )
@@ -880,6 +893,14 @@ are given then the addresses are extracted from the message being sent.
 
 Send a HELO (or EHLO) command to the server with the given name.
 
+=item Port
+
+Port number to connect to on remote host
+
+=item Debug
+
+Debug value to pass to Net::SMPT, see <Net::SMTP>
+
 =back
 
 =item nntppost ( [ OPTIONS ] )
@@ -924,11 +945,11 @@ L<Mail::Address>
 
 =head1 AUTHOR
 
-Graham Barr <gbarr@pobox.com>
+Graham Barr.  Maintained by Mark Overmeer <mailtools@overmeer.net>
 
 =head1 COPYRIGHT
 
-Copyright (c) 1995-7 Graham Barr. All rights reserved. This program is free
+Copyright (c) 1995-2001 Graham Barr. All rights reserved. This program is free
 software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
 
